==> cloudtik-1.0.7-cp38-cp38-manylinux2014_x86_64.whl: cloudtik/runtime/flink/api.py <==
"""IMPORTANT: this is an experimental interface and not currently stable."""

from typing import Union

from cloudtik.core.api import Cluster, ThisCluster
from cloudtik.runtime.flink.utils import request_rest_jobs, request_rest_yarn, get_runtime_default_storage, \
    get_runtime_services


class FlinkCluster(Cluster):
    def __init__(self, cluster_config: Union[dict, str], should_bootstrap: bool = True) -> None:
        """Create a Flink cluster object to operate on with this API.

        Args:
            cluster_config (Union[str, dict]): Either the config dict of the
                cluster, or a path pointing to a file containing the config.
        """
        Cluster.__init__(self, cluster_config, should_bootstrap)

    def jobs(self, endpoint: str):
        """Make a rest request to Flink History Server

        Args:
            endpoint (str): The Spark history server rest endpoint to request
        """
        return request_rest_jobs(self.config, endpoint)

    def yarn(self, endpoint: str):
        """Make a rest request to YARN Resource Manager

        Args:
            endpoint (str): The Spark history server rest endpoint to request
        """
        return request_rest_yarn(self.config, endpoint)

    def get_default_storage(self):
        return get_runtime_default_storage(self.config)

    def get_services(self):
        return get_runtime_services(self.config, "")


class ThisFlinkCluster(ThisCluster):
    def __init__(self) -> None:
        """Create a Flink cluster object to operate on with this API on head."""
        ThisCluster.__init__(self)

    def jobs(self, endpoint: str):
        """Make a rest request to Flink History Server

        Args:
            endpoint (str): The Spark history server rest endpoint to request
        """
        return request_rest_jobs(self.config, endpoint, on_head=True)

    def yarn(self, endpoint: str):
        """Make a rest request to YARN Resource Manager

        Args:
            endpoint (str): The Spark history server rest endpoint to request
        """
        return request_rest_yarn(self.config, endpoint, on_head=True)

    def get_default_storage(self):
        return get_runtime_default_storage(self.config)

    def get_services(self):
        return get_runtime_services(self.config)

==> cloudtik-1.5.0-cp38-cp38-manylinux2014_x86_64.whl: cloudtik/runtime/flink/api.py <==
"""IMPORTANT: this is an experimental interface and not currently stable."""

from typing import Union, Optional

from cloudtik.core.api import Cluster, ThisCluster
from cloudtik.runtime.flink.utils import request_rest_jobs, get_runtime_default_storage, \
    get_runtime_endpoints


class FlinkCluster(Cluster):
    def __init__(
            self, cluster_config: Union[dict, str],
            should_bootstrap: bool = True,
            no_config_cache: bool = True,
            verbosity: Optional[int] = None) -> None:
        """Create a Flink cluster object to operate on with this API.

        Args:
            cluster_config (Union[str, dict]): Either the config dict of the
                cluster, or a path pointing to a file containing the config.
        """
        super().__init__(
            cluster_config, should_bootstrap,
            no_config_cache, verbosity)

    def jobs(self, endpoint: str):
        """Make a rest request to Flink History Server

        Args:
            endpoint (str): The Spark history server rest endpoint to request
        """
        return request_rest_jobs(self.config, endpoint)

    def get_default_storage(self):
        return get_runtime_default_storage(self.config)

    def get_endpoints(self):
        return get_runtime_endpoints(self.config)


class ThisFlinkCluster(ThisCluster):
    def __init__(self, verbosity: Optional[int] = None) -> None:
        """Create a Flink cluster object to operate on with this API on head."""
        super().__init__(verbosity)

    def jobs(self, endpoint: str):
        """Make a rest request to Flink History Server

        Args:
            endpoint (str): The Spark history server rest endpoint to request
        """
        return request_rest_jobs(self.config, endpoint, on_head=True)

    def get_default_storage(self):
        return get_runtime_default_storage(self.config)

    def get_endpoints(self):
        return get_runtime_endpoints(self.config)
